@@ -5,6 +5,7 @@ from pyogrio.core import (
     read_info,
     set_gdal_config_options,
     get_gdal_config_option,
+    get_gdal_data_path,
     __gdal_version__,
     __gdal_version_string__,
     __gdal_geos_version__,
@@ -23,6 +24,7 @@ __all__ = [
     "read_info",
     "set_gdal_config_options",
     "get_gdal_config_option",
+    "get_gdal_data_path",
     "read_dataframe",
     "write_dataframe",
     "__gdal_version__",
